@@ -39,6 +39,7 @@ __all__ = (
     "TransitGatewayConnectPeerAssociationStateType",
     "TransitGatewayRegistrationStateType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -336,10 +337,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -347,3 +350,14 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_global_networks",
+    "get_connections",
+    "get_customer_gateway_associations",
+    "get_devices",
+    "get_link_associations",
+    "get_links",
+    "get_sites",
+    "get_transit_gateway_connect_peer_associations",
+    "get_transit_gateway_registrations",
+]
